package websocket

import (
	"encoding/json"
	"fmt"
	"github.com/charmbracelet/log"
	"github.com/gorilla/websocket"

	GoTomato "git.smsvc.net/pomodoro/GoTomato/pkg/models"
)

var Done = make(chan struct{})

// Receives websocket messages and write them to `channel`
func (c Client) ProcessServerMessages(channel chan<- GoTomato.ServerMessage) {
	var serverMessage GoTomato.ServerMessage

	defer close(Done)

	for {
		_, message, err := c.Conn.ReadMessage()
		if err != nil {
			if websocket.IsCloseError(err, websocket.CloseNormalClosure) {
				// Ignore normal closure and exit gracefully
				return
			}
			// Log any other errors
			fmt.Println()
			log.Error("Read error!", "reason", err)
			return
		}

		err = json.Unmarshal(message, &serverMessage)
		if err != nil {
			log.Error("Error unmarshalling!", "reason", err)
			continue
		}

		channel <- serverMessage
	}
}
